markdown

package
v0.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 25, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Renderer

type Renderer struct {
	// contains filtered or unexported fields
}

Renderer renders markdown for the TUI using glamour.

func NewRenderer

func NewRenderer(width int) *Renderer

NewRenderer creates a markdown renderer at the given width.

func (*Renderer) RenderFinal

func (r *Renderer) RenderFinal(content string) string

RenderFinal renders final markdown to ANSI-formatted terminal output.

func (*Renderer) SetWidth

func (r *Renderer) SetWidth(width int)

SetWidth rebuilds the underlying renderer when terminal width changes.

func (*Renderer) Width

func (r *Renderer) Width() int

Width reports the current renderer width.

Jump to